==> telephone-sqlserver-3.0.15.jar: filiale/furuike/sqls/phreport2.sql <==
SELECT t1.column1, t2.chaigai, t3.xielou, t4.baoxiu, t5.zengzhi, t6.richang, t7.tousu
FROM (SELECT '派单' as column1
      UNION
      SELECT '完工' as column1) t1
         LEFT JOIN (SELECT '派单' as column1, count(*) as chaigai
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%燃气设施拆改%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as chaigai
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%燃气设施拆改%') t2
                                  ON t1.processid = t2.f_processId) t2 ON t1.column1 = t2.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as xielou
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%燃气泄漏%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as xielou
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%燃气泄漏%') t2
                                  ON t1.processid = t2.f_processId) t3 ON t1.column1 = t3.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as baoxiu
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%报修%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as baoxiu
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%报修%') t2
                                  ON t1.processid = t2.f_processId) t4 ON t1.column1 = t4.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as zengzhi
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%增值服务%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as zengzhi
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%增值服务%') t2
                                  ON t1.processid = t2.f_processId) t5 ON t1.column1 = t5.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as richang
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%日常服务%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as richang
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%日常服务%') t2
                                  ON t1.processid = t2.f_processId) t6 ON t1.column1 = t6.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as tousu
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%投诉%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as tousu
                    FROM (SELECT processid FROM activityins WHERE defname = '维修完成' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%投诉%') t2
                                  ON t1.processid = t2.f_processId) t7 ON t1.column1 = t7.column1

==> telephone-sqlserver-3.0.68.jar: filiale/furuike/sqls/phreport2.sql <==
SELECT t1.column1, t2.chaigai, t3.xielou, t4.baoxiu, t5.zengzhi, t6.richang, t7.tousu
FROM (SELECT '派单' as column1
      UNION
      SELECT '完工' as column1) t1
         LEFT JOIN (SELECT '派单' as column1, count(*) as chaigai
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%燃气设施拆改%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as chaigai
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%燃气设施拆改%') t2
                                  ON t1.processid = t2.f_processId) t2 ON t1.column1 = t2.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as xielou
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%燃气泄漏%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as xielou
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%燃气泄漏%') t2
                                  ON t1.processid = t2.f_processId) t3 ON t1.column1 = t3.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as baoxiu
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%报修%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as baoxiu
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%报修%') t2
                                  ON t1.processid = t2.f_processId) t4 ON t1.column1 = t4.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as zengzhi
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%增值服务%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as zengzhi
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%增值服务%') t2
                                  ON t1.processid = t2.f_processId) t5 ON t1.column1 = t5.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as richang
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%日常服务%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as richang
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%日常服务%') t2
                                  ON t1.processid = t2.f_processId) t6 ON t1.column1 = t6.column1
         LEFT JOIN (SELECT '派单' as column1, count(*) as tousu
                    FROM t_serviceworkorder
                    WHERE failure LIKE '%投诉%' AND f_created_date between '{startDate}' and '{endDate}'
                    UNION
                    SELECT '完工' as column1, count(*) as tousu
                    FROM (SELECT processid FROM activityins WHERE (defname = '维修完成' or defname = '工单审核' ) and state = '开始活动' AND sendtime between '{startDate}' and '{endDate}') t1
                             JOIN (SELECT f_processId FROM t_serviceworkorder WHERE failure LIKE '%投诉%') t2
                                  ON t1.processid = t2.f_processId) t7 ON t1.column1 = t7.column1
